@@ -3,13 +3,17 @@ from django.test import TestCase
 from facebook_pages.factories import PageFactory
 from facebook_applications.models import Application
 from facebook_users.models import User
+from factories import PostFactory, CommentFactory
 from models import Post, PostOwner, Comment, Page
 from datetime import datetime, timedelta
 
 PAGE_ID = '19292868552'
 POST1_ID = '19292868552_10150189643478553'
-POST2_ID = '40796308305_10151982794203306'
-COMMENT1_ID = '19292868552_10150189643478553_16210808'
+POST2_ID = '100001341687090_632170373504346'
+COMMENT1_ID = '19292868552_10150475844632302_20258978'
+
+POST_WITH_MANY_LIKES_ID = '19292868552_10151516882688553'
+POST_WITH_MANY_COMMENTS_ID = '19292868552_10150475844632302'
 
 class FacebookPostsTest(TestCase):
 
@@ -27,7 +31,7 @@ class FacebookPostsTest(TestCase):
         self.assertEqual(post.name, u'Developer Roadmap Update: Moving to OAuth 2.0 + HTTPS')
         self.assertEqual(post.type, 'link')
         self.assertEqual(post.status_type, 'app_created_story')
-        self.assertEqual(post.created_time, datetime(2011,5,10,22,35,38))
+        self.assertTrue(isinstance(post.created_time, datetime))
         self.assertTrue('We continue to make Platform more secure for users' in post.description)
         self.assertTrue(len(post.icon) > 0)
         self.assertTrue(len(post.picture) > 20)
@@ -51,15 +55,14 @@ class FacebookPostsTest(TestCase):
     def test_fetch_post_authors_owners(self):
 
         # post on the page by page
-        Post.remote.fetch(POST1_ID)
-        post = Post.objects.all()[0]
-        page = Page.objects.all()[0]
-
         author = {
             "name": "Facebook Developers",
             "category": "Product/service",
             "id": "19292868552"
         }
+        Post.remote.fetch(POST1_ID)
+        post = Post.objects.get(graph_id=POST1_ID)
+        page = Page.objects.get(graph_id=author['id'])
 
         self.assertEqual(page.graph_id, author['id'])
         self.assertEqual(page.name, author['name'])
@@ -69,21 +72,20 @@ class FacebookPostsTest(TestCase):
         self.assertEqual(post.author, page)
 
         # post on the page by user
-        Post.remote.fetch(POST2_ID)
-        post = Post.objects.all()[0]
-        user = User.objects.all()[0]
-        postowner = PostOwner.objects.all()[0]
-
         author = {
-            "name": "Calum Gaterr",
-            "id": "100001882194092"
+            "id": "100000550622902",
+            "name": "Danny Reitzloff"
         }
         owners = [{
-            "name": "Coca-Cola",
-            "category": "Food/beverages",
-            "id": "40796308305"
+            "id": "100001341687090",
+            "name": "Rainbow Gathering"
         }]
 
+        Post.remote.fetch(POST2_ID)
+        post = Post.objects.get(graph_id=POST2_ID)
+        user = User.objects.get(graph_id=author['id'])
+        postowner = PostOwner.objects.all()[0]
+
         self.assertEqual(post.author, user)
         self.assertEqual(post.owners.all()[0], postowner)
         # self.assertEqual(post.owners_json, owners) # TODO: fix saving json as string
@@ -94,58 +96,63 @@ class FacebookPostsTest(TestCase):
 
         self.assertEqual(postowner.owner.name, owners[0]['name'])
         self.assertEqual(postowner.owner.graph_id, owners[0]['id'])
-        self.assertEqual(postowner.owner.category, owners[0]['category'])
 
     def test_fetch_post_comments(self):
 
-        Post.remote.fetch(POST1_ID)
-        post = Post.objects.all()[0]
+        post = PostFactory(graph_id=POST_WITH_MANY_COMMENTS_ID)
 
         self.assertEqual(Comment.objects.count(), 0)
+
         comments = post.fetch_comments(limit=100)
-        self.assertTrue(Comment.objects.count() == comments.count() == 100)
+        self.assertEqual(comments.count(), 100)
+        self.assertEqual(comments.count(), Comment.objects.count())
+        self.assertEqual(comments.count(), post.comments.count())
 
         comments = post.fetch_comments(all=True)
-        self.assertTrue(Comment.objects.count() > 100)
-        self.assertTrue(Comment.objects.count() == comments.count() == post.comments_real_count)
+        self.assertTrue(post.comments_count > 1000)
+        self.assertEqual(post.comments_count, Comment.objects.count())
+        self.assertEqual(post.comments_count, comments.count())
+        self.assertEqual(post.comments_count, post.comments.count())
 
         comment = comments.get(graph_id=COMMENT1_ID)
-        user = User.objects.get(graph_id='100001650376589')
+        user = User.objects.get(graph_id='100000422272038')
 
-        self.assertEqual(user.name, 'Whdtabbasiwahd Abbas')
+        self.assertEqual(user.name, 'Jordan Alvarez')
 
         self.assertEqual(comment.post, post)
         self.assertEqual(comment.author, user)
-        self.assertEqual(comment.message, 'ok')
+        self.assertEqual(comment.message, 'PLAYDOM? bahhhhhhhhh ZYNGA RULES!')
         self.assertEqual(comment.can_remove, False)
         self.assertEqual(comment.user_likes, False)
-        self.assertEqual(comment.created_time, datetime(2011,5,10,22,36,29))
-        self.assertTrue(comment.likes_count > 400)
-
-#        self.assertEqual(post.comments.count(), post.comments_count) # TODO: fix strange ammount of real comments
-#        self.assertEqual(post.comments_real_count, post.comments_count)
+        self.assertTrue(isinstance(comment.created_time, datetime))
+        self.assertTrue(comment.likes_count > 5)
 
     def test_fetch_post_likes(self):
 
-        Post.remote.fetch(POST1_ID)
-        post = Post.objects.all()[0]
+        post = PostFactory(graph_id=POST_WITH_MANY_LIKES_ID)
 
         self.assertEqual(post.like_users.count(), 0)
-        post.fetch_likes()
-        self.assertEqual(post.likes_real_count, User.objects.count())
-#        self.assertEqual(post.like_users.count(), post.likes_count) # TODO: fix strange ammount of real likes
-#        self.assertEqual(post.likes_real_count, post.likes_count)
+        self.assertEqual(User.objects.count(), 1)
+
+        users = post.fetch_likes(all=True)
+        self.assertTrue(users.count() > 1000)
+        self.assertEqual(post.likes_count, users.count())
+        self.assertEqual(post.likes_count, User.objects.count() - 1)
+        self.assertEqual(post.likes_count, post.like_users.count())
 
     def test_fetch_comment_likes(self):
 
-        post = Post.remote.fetch(POST1_ID)
-        comment = Comment.remote.fetch(COMMENT1_ID, extra_fields={'post_id': post.id})
+        post = PostFactory(graph_id=POST1_ID)
+        comment = CommentFactory(graph_id=COMMENT1_ID, post=post)
 
         self.assertEqual(comment.like_users.count(), 0)
-        comment.fetch_likes()
-        self.assertEqual(comment.likes_real_count, User.objects.count())
-#        self.assertEqual(comment.like_users.count(), comment.likes_count) # TODO: fix strange ammount of real likes
-#        self.assertEqual(comment.likes_real_count, comment.likes_count)
+        self.assertEqual(User.objects.count(), 2)
+
+        users = comment.fetch_likes(all=True)
+        self.assertTrue(users.count() > 7)
+        self.assertEqual(comment.likes_count, users.count())
+        self.assertEqual(comment.likes_count, User.objects.count() - 2)
+        self.assertEqual(comment.likes_count, comment.like_users.count())
 
     def test_fetch_posts_of_page(self):
 
@@ -164,20 +171,4 @@ class FacebookPostsTest(TestCase):
         posts_count1 = Post.objects.count()
 
         self.assertTrue(posts_count1 < posts_count)
-        self.assertEqual(posts_count1, len(posts))
-
-
-    def test_fetch_posts_of_page_owners_integrity_problem(self):
-        '''
-        Some posts have owners in response and inside transaction we get
-        IntegrityError: duplicate key value violates unique constraint "facebook_posts_postowner_post_id_6e3cdbee7eca490e_uniq"
-        DETAIL:  Key (post_id, owner_content_type_id, owner_id)=(63087, 82, 1065) already exists.
-        '''
-        page = PageFactory(graph_id=224226267619403)
-
-        self.assertEqual(Post.objects.count(), 0)
-
-        posts = page.fetch_posts(limit=100)
-
-        self.assertEqual(Post.objects.count(), 100)
-        self.assertEqual(Post.objects.count(), len(posts))
\ No newline at end of file
+        self.assertEqual(posts_count1, len(posts))
\ No newline at end of file
